      SUBROUTINE DAHELP(IBUFFR,MAXBFR,LOWBFR,IQUERY)
C     RENBR(/DETERMINE NUMBER OF LEADING QUESTION MARKS)
C
C     DONALD BARTH, HARVARD BUSINESS SCHOOL
C
C     IBUFFR = ARRAY CONTAINING CHARACTERS READ BY MULTIPLE
C              OF A1 FORMAT.
C     MAXBFR = SUBSCRIPT   OF   IBUFFR    ARRAY    LOCATION
C              CONTAINING RIGHTMOST CHARACTER.
C     LOWBFR = SUBSCRIPT OF FIRST LOCATION IN IBUFFR  ARRAY
C              TO  BE  TESTED.  LOWBFR IS RETURNED POINTING
C              TO  THE  FIRST  NON-QUESTION  MARK  PRINTING
C              CHARACTER  IN BUFFER OR BEYOND END OF BUFFER
C              IF NO OTHER PRINTING  CHARACTERS  APPEAR  IN
C              BUFFER.
C     IQUERY = 0, RETURNED IF NO QUESTION MARKS  APPEAR  AT
C              START OF TEXT IN IBUFFR ARRAY.
C            = GREATER  THAN  ZERO,  IQUERY  IS  NUMBER  OF
C              QUESTION  MARKS  FOUND  AT  START OF TEXT IN
C              IBUFFR ARRAY.
C
      DIMENSION IBUFFR(MAXBFR)
      DATA IQUEST,ISPACE,ITAB/1H?,1H ,1H	/
      IQUERY=0
    1 IF(LOWBFR.GT.MAXBFR)GO TO 3
      LETTER=IBUFFR(LOWBFR)
      IF(LETTER.EQ.ISPACE)GO TO 2
      IF(LETTER.EQ.ITAB)GO TO 2
      IF(LETTER.NE.IQUEST)GO TO 3
      IQUERY=IQUERY+1
    2 LOWBFR=LOWBFR+1
      GO TO 1
    3 RETURN
C098245027474?
      END

